require "open-uri"
require "nokogiri"

module Nx
  class DoubanCelebrity
    def initialize(url)
      @url = url
      @doc = Nokogiri::HTML(URI.open(url))
      @info_list = @doc.css("#headline>.info li span")
    end

    def url
      @url
    end

    def to_h
      methods = (public_methods(false) - [__method__])
      methods.map do |method|
        [method, send(method)]
      end.to_h
    end

    def title
      @doc.css("#content>h1").text
    end

    # 头像
    def avatar
      el = @doc.css("#headline .pic img")
      el.attribute("src").value
    end

    # 性别
    def sex
      el = @info_list.find do |item|
        item.text.include? "性别"
      end
      clean_string(el.nil? ? "" : el.next.text)
    end

    # 星座
    def zodiac
      el = @info_list.find do |item|
        item.text.include? "星座"
      end
      clean_string(el.nil? ? "" : el.next.text)
    end

    # 职业
    def occupation
      el = @info_list.find do |item|
        item.text.include? "职业"
      end
      clean_string(el.nil? ? "" : el.next.text)
    end

    # 出生日期
    def birthday
      el = @info_list.find do |item|
        item.text.include? "出生日期"
      end
      clean_string(el.nil? ? "" : el.next.text)
    end

    # 出生地
    def birth_place
      el = @info_list.find do |item|
        item.text.include? "出生地"
      end
      clean_string(el.nil? ? "" : el.next.text)
    end

    # imdb编号
    def imdb_url
      el = @info_list.find do |item|
        item.text.include? "imdb编号"
      end
      code = clean_string(el.nil? ? "" : el.next_element.text)
      "https://www.imdb.com/name/#{code}"
    end

    # 影人简介
    def summary
      el = @doc.at_css("#intro > .bd")
      clean_string el.inner_html
    end

    private

    def clean_string(str)
      str.tr!(":", "")
      str.tr!("\n", "")
      str.strip!
      str.delete("　　")
    end
  end
end
